Learn R Programming

soilphysics (version 5.1)

plotCIsigmaP: Percentile Confidence Intervals for Simulated Preconsolidation Stress

Description

Build and plot percentile confidence intervals for preconsolidation stress simulated from simSigmaP.

Usage

plotCIsigmaP(msim, conf.level = 0.95, shade.col = "orange", 
	ordered = TRUE, xlim = NULL, xlab = expression(sigma[P]), 
	las = 1, mar = c(4.5, 6.5, 2, 1), ...)

Value

A numeric matrix containing the simulated mean, coefficient of variation, lower and upper CI limits and the name of the method used to calculate the preconsolidation stress.

Arguments

msim

an object of class "simSigmaP".

conf.level

the confidence level for the intervals.

shade.col

a character or number indicating the color of the shaded area delimiting each CI. See colors.

ordered

logical; should the intervals be displayed according to the value of the simulated mean?

xlim

optional; a numeric vector of length two containing the limits of the x-axis.

xlab

optional; a character indicating the x-axis label.

las

optional; see par.

mar

optional; see par.

...

further graphical parameters; see par.

Author

Anderson Rodrigo da Silva <anderson.agro@hotmail.com>

See Also

simSigmaP, sigmaP

Examples

Run this code
# input data: stress and void ratio
pres <- c(1, 12.5, 25, 50, 100, 200, 400, 800, 1600)
VR <- c(1.43, 1.41, 1.40, 1.39, 1.35, 1.31, 1.25, 1.18, 1.12)

# simulation (may take a few seconds)
simres <- simSigmaP(VR, pres, nsim = 30)
head(simres)

# percentile confidence intervals
ci <- plotCIsigmaP(simres, conf.level = 0.95, 
	shade.col = "blue", ordered = TRUE)
print(ci)

# End (Not run)

Run the code above in your browser using DataLab